﻿// Global Paragraph Styles Remapping
// Глобальное переназначение абзацных стилей
// densen
// v.1 (15.03.2023)

// Присутствуют три функции переназначения абзацных стилей: 

// remapDownShort (Вниз на определенное количество абзацей)
// remapDownShort ("Стиль 1", "Стиль 2", "Стиль 3", количество)
// Если после абзаца со "Стиль 1" следует абзац со "Стиль 2", то [количество] абзацей, следующих после абзаца со "Стиль 1" и имеющих "Стиль 2", будут переназначены в "Стиль 3"

// remapDownLong (Вниз, пока не встретится другой стиль)
// remapDownLong ("Стиль 1", "Стиль 2", "Стиль 3")
// Если после абзаца со "Стиль 1" следует абзац со "Стиль 2", то до тех пор, пока абзацы, следующие за абзацем со "Стиль 1", будут иметь "Стиль 2", все они будут переназначены в "Стиль 3"

// remapUpShort (Вверх на определенное количество абзацей)
// remapUpShort ("Стиль 1", "Стиль 2", "Стиль 3", количество)
// Если абзацу со "Стиль 1" предшествует абзац со "Стиль 2", то [количество] абзацей, предшествующих абзацу со "Стиль 1" и имеющих "Стиль 2", будут переназначены в "Стиль 3"

// Если абзацные стили находятся вне групп, то можно подставлять имя стиля в кавычках - "Text", "Head", "Мой стиль" и т.д.
// Если абзацные стили находятся в группах, или в группах, расположенных в группах, то для удобства можно вводить переменные (обязательно прочитайте раздел "ВНИМАНИЕ!!!")
// var MT = app.activeDocument.paragraphStyleGroups.item("Article").paragraphStyles.item("Main Text"); // Переменная имени стиля "Main Text", расположенного в группе "Article"
// var DOI = app.activeDocument.paragraphStyleGroups.item("Article").paragraphStyleGroups.item("Head").paragraphStyles.item("DOI"); // Переменная имени стиля "DOI", расположенного в группе "Head", которая в свою очередь расположена в группе "Article"

// ВНИМАНИЕ!!!
// Если требуется найти какой-либо стиль в тексте ("Стиль 1" или "Стиль 2"), и этот стиль находится в группе, то к переменной стиля добавляется ".name".
// В этом случае, если задана переменная:
// var MT = app.activeDocument.paragraphStyleGroups.item("Article").paragraphStyles.item("Main Text")
// ...то вместо "Стиль 1" и "Стиль 2" нужно подставлять переменные с суффиксом ".name", то есть MT.name и т.п.
// Если требуется заменить на какой-то стиль в тексте, и этот стиль находится в группе, то вместо "Стиль 3" ставится просто переменная MT.

//##################################################

app.doScript("globalParaStylesRemap()",ScriptLanguage.JAVASCRIPT,[],UndoModes.ENTIRE_SCRIPT,"Global Paragraph Styles Remapping");

globalParaStylesRemap()

function globalParaStylesRemap(){
    var myDoc = app.activeDocument;
    var LL = myDoc.paragraphStyleGroups.item("Article").paragraphStyles.item("Literature Level");
    var MT = myDoc.paragraphStyleGroups.item("Article").paragraphStyles.item("Main Text");
    var LIT = myDoc.paragraphStyleGroups.item("Article").paragraphStyleGroups.item("Text").paragraphStyles.item("Literature");
    
    remapDownLong (LL.name, MT.name, LIT);
    remapDownShort ("01", "00", "02", 3);
    remapUpShort ("01", "00", "02", 4);
    }

function remapDownShort (first, next, updated_next, steps) { // ("Стиль 1", "Стиль 2", "Стиль 3", количество)
    for (var i = 0; i < app.activeDocument.stories.length; i++){  
        var s = app.activeDocument.stories.item(i);  
        for (var j = s.paragraphs.length - 1; j > -1; j--){  
            try{
                if (s.paragraphs.item(j).appliedParagraphStyle.name == first && s.paragraphs.item(j+1).appliedParagraphStyle.name == next) {
                s.paragraphs.item(j+1).appliedParagraphStyle = updated_next;
                var k = j + 2;
                var l = k + steps - 1;
                for (k; k < l; k++){
                    while (s.paragraphs.item(k).appliedParagraphStyle.name == next && k < s.paragraphs.length) {
                        s.paragraphs.item(k).appliedParagraphStyle = updated_next;
                        }
                    }
                }
            } catch (e) {}
        }  
    }
}


function remapDownLong (first, next, updated_next) { // ("Стиль 1", "Стиль 2", "Стиль 3")
    for (var i = 0; i < app.activeDocument.stories.length; i++){  
        var s = app.activeDocument.stories.item(i);  
        for (var j = s.paragraphs.length - 1; j > -1; j--){  
            try{
                if (s.paragraphs.item(j).appliedParagraphStyle.name == first && s.paragraphs.item(j+1).appliedParagraphStyle.name == next) {
                s.paragraphs.item(j+1).appliedParagraphStyle = updated_next;
                var k = j + 2;
                while (s.paragraphs.item(k).appliedParagraphStyle.name == next && k < s.paragraphs.length) {
                    s.paragraphs.item(k).appliedParagraphStyle = updated_next;
                    k++;
                    }
                }
            } catch (e) {}
        }  
    }
}


function remapUpShort (first, previous, updated_previous, steps) { // ("Стиль 1", "Стиль 2", "Стиль 3", количество)
    for (var i = 0; i < app.activeDocument.stories.length; i++){  
        var s = app.activeDocument.stories.item(i);  
        for (var j = s.paragraphs.length - 1; j > -1; j--){  
            try{
                if (s.paragraphs.item(j).appliedParagraphStyle.name == first && s.paragraphs.item(j-1).appliedParagraphStyle.name == previous) {
                s.paragraphs.item(j-1).appliedParagraphStyle = updated_previous;
                var k = j - steps;
                var l = k + steps - 1;
                for (k; k < l; k++){
                    while (s.paragraphs.item(k).appliedParagraphStyle.name == previous && k < s.paragraphs.length) {
                        s.paragraphs.item(k).appliedParagraphStyle = updated_previous;
                        }
                    }
                }
            } catch (e) {}
        }  
    }
}